@@ -1,5 +1,5 @@
-/* Define SHMLBA.  Generic version.
-   Copyright (C) 2018-2023 Free Software Foundation, Inc.
+/* Define SHMLBA.  ARM version.
+   Copyright (C) 2018-2024 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,7 +23,7 @@
 __BEGIN_DECLS
 
 /* Segment low boundary address multiple.  */
-#define SHMLBA		(__getpagesize ())
+#define SHMLBA		(__getpagesize () << 2)
 extern int __getpagesize (void) __THROW __attribute__ ((__const__));
 
 __END_DECLS
