@@ -22,8 +22,8 @@
 /* Flags for signalfd.  */
 enum
   {
-    SFD_CLOEXEC = 0x400000,
+    SFD_CLOEXEC = 02000000,
 #define SFD_CLOEXEC SFD_CLOEXEC
-    SFD_NONBLOCK = 0x004000
+    SFD_NONBLOCK = 00004000
 #define SFD_NONBLOCK SFD_NONBLOCK
   };
