@@ -1,11 +1,11 @@
 /* Generated at libc build time from syscall list.  */
-/* The system call list corresponds to kernel 6.4.  */
+/* The system call list corresponds to kernel 6.9.  */
 
 #ifndef _SYSCALL_H
 # error "Never use <bits/syscall.h> directly; include <sys/syscall.h> instead."
 #endif
 
-#define __GLIBC_LINUX_VERSION_CODE 394240
+#define __GLIBC_LINUX_VERSION_CODE 395520
 
 #ifdef __NR_FAST_atomic_update
 # define SYS_FAST_atomic_update __NR_FAST_atomic_update
@@ -143,6 +143,10 @@
 # define SYS_cacheflush __NR_cacheflush
 #endif
 
+#ifdef __NR_cachestat
+# define SYS_cachestat __NR_cachestat
+#endif
+
 #ifdef __NR_capget
 # define SYS_capget __NR_capget
 #endif
@@ -375,6 +379,10 @@
 # define SYS_fchmodat __NR_fchmodat
 #endif
 
+#ifdef __NR_fchmodat2
+# define SYS_fchmodat2 __NR_fchmodat2
+#endif
+
 #ifdef __NR_fchown
 # define SYS_fchown __NR_fchown
 #endif
@@ -491,14 +499,26 @@
 # define SYS_futex __NR_futex
 #endif
 
+#ifdef __NR_futex_requeue
+# define SYS_futex_requeue __NR_futex_requeue
+#endif
+
 #ifdef __NR_futex_time64
 # define SYS_futex_time64 __NR_futex_time64
 #endif
 
+#ifdef __NR_futex_wait
+# define SYS_futex_wait __NR_futex_wait
+#endif
+
 #ifdef __NR_futex_waitv
 # define SYS_futex_waitv __NR_futex_waitv
 #endif
 
+#ifdef __NR_futex_wake
+# define SYS_futex_wake __NR_futex_wake
+#endif
+
 #ifdef __NR_futimesat
 # define SYS_futimesat __NR_futimesat
 #endif
@@ -847,6 +867,10 @@
 # define SYS_listen __NR_listen
 #endif
 
+#ifdef __NR_listmount
+# define SYS_listmount __NR_listmount
+#endif
+
 #ifdef __NR_listxattr
 # define SYS_listxattr __NR_listxattr
 #endif
@@ -879,6 +903,18 @@
 # define SYS_lsetxattr __NR_lsetxattr
 #endif
 
+#ifdef __NR_lsm_get_self_attr
+# define SYS_lsm_get_self_attr __NR_lsm_get_self_attr
+#endif
+
+#ifdef __NR_lsm_list_modules
+# define SYS_lsm_list_modules __NR_lsm_list_modules
+#endif
+
+#ifdef __NR_lsm_set_self_attr
+# define SYS_lsm_set_self_attr __NR_lsm_set_self_attr
+#endif
+
 #ifdef __NR_lstat
 # define SYS_lstat __NR_lstat
 #endif
@@ -891,6 +927,10 @@
 # define SYS_madvise __NR_madvise
 #endif
 
+#ifdef __NR_map_shadow_stack
+# define SYS_map_shadow_stack __NR_map_shadow_stack
+#endif
+
 #ifdef __NR_mbind
 # define SYS_mbind __NR_mbind
 #endif
@@ -2259,6 +2299,10 @@
 # define SYS_statfs64 __NR_statfs64
 #endif
 
+#ifdef __NR_statmount
+# define SYS_statmount __NR_statmount
+#endif
+
 #ifdef __NR_statx
 # define SYS_statx __NR_statx
 #endif
